==> nextcloud-app-notes-4.12.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/notes/l10n/ast.js <==
OC.L10N.register(
    "notes",
    {
    "Notes" : "Notes",
    "Create new note" : "Crear un rol",
    "More notes" : "Más notes",
    "Error" : "Error",
    "New note" : "Nota nueva",
    "Notes settings" : "Configuración de Notes",
    "Open in rich text mode" : "Abrir nel mou de testu arriquecíu",
    "Open in edit mode" : "Abrir nel mou d'edición",
    "Open in preview mode" : "Abrir nel mou de previsualización",
    "CTRL" : "CTRL",
    "ALT" : "ALT",
    "SHIFT" : "MAYÚS",
    "Basics" : "Lo básico",
    "Write down your thoughts without any distractions." : "Escribi cualesquier pensamientu ensin nenguna distraición.",
    "Organize your notes in categories." : "Organiza les notes per categoríes.",
    "Notes path" : "Camín de les notes",
    "File extension" : "Estensión de los ficheros",
    "Shortcuts" : "Atayos",
    "Use shortcuts to quickly navigate this app." : "Usa los atayos pa navegar aína per esta aplicación.",
    "Shortcut" : "Atayos",
    "Action" : "Aición",
    "Mobile apps" : "Aplicaciones pa móviles",
    "All notes" : "Toles notes",
    "Categories" : "Categories",
    "No notes yet" : "Nun hai nenguna nota",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Instala l'aplicación nel móvil pa acceder a les notes en cualesquier llugar.",
    "Rename" : "Rename",
    "Delete note" : "Desaniciar la nota",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Editar",
    "Exit full screen" : "Colar de la pantalla completa",
    "Full screen" : "Pantalla completa",
    "Today" : "Güei",
    "Yesterday" : "Ayeri",
    "This week" : "Esta selmana",
    "Last week" : "La selmana pasada",
    "This month" : "Esti mes",
    "Last month" : "El mes pasáu",
    "Search for notes" : "Buscar notes",
    "Loading …" : "Cargando…",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Comienza a escribir notes al calcar en «{newnote}» na navegación de l'aplicación.",
    "Note not found." : "Nun s'atopó la nota",
    "Note is locked." : "La nota ta bloquiada",
    "Uncategorized" : "Ensin categoría",
    "Tasks" : "Xeres",
    "Nextcloud, a safe home for all your data" : "Nexcloud, un llugar seguru pa los datos personales",
    "Development Mode" : "Mou de desendocu"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-notes-4.12.4-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/notes/l10n/ast.js <==
OC.L10N.register(
    "notes",
    {
    "Notes" : "Notes",
    "Create new note" : "Crear un rol",
    "More notes" : "Más notes",
    "Error" : "Error",
    "New note" : "Nota nueva",
    "Notes settings" : "Configuración de Notes",
    "File extension" : "Estensión de los ficheros",
    "Files" : "Ficheros",
    "Mobile apps" : "Aplicaciones pa móviles",
    "Shortcuts" : "Atayos",
    "All notes" : "Toles notes",
    "Categories" : "Categories",
    "No notes yet" : "Nun hai nenguna nota",
    "Rename" : "Rename",
    "Delete note" : "Desaniciar la nota",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Editar",
    "Exit full screen" : "Colar de la pantalla completa",
    "Full screen" : "Pantalla completa",
    "Today" : "Güei",
    "Yesterday" : "Ayeri",
    "This week" : "Esta selmana",
    "Last week" : "La selmana pasada",
    "This month" : "Esti mes",
    "Last month" : "El mes pasáu",
    "Search for notes" : "Buscar notes",
    "Loading …" : "Cargando…",
    "Write down your thoughts without any distractions." : "Escribi cualesquier pensamientu ensin nenguna distraición.",
    "Organize your notes in categories." : "Organiza les notes per categoríes.",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Comienza a escribir notes al calcar en «{newnote}» na navegación de l'aplicación.",
    "Note not found." : "Nun s'atopó la nota",
    "Note is locked." : "La nota ta bloquiada",
    "Uncategorized" : "Ensin categoría",
    "Tasks" : "Xeres",
    "Nextcloud, a safe home for all your data" : "Nexcloud, un llugar seguru pa los datos personales",
    "Development Mode" : "Mou de desendocu"
},
"nplurals=2; plural=(n != 1);");
